/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.yifu.social.entity;

import com.alibaba.excel.annotation.ExcelProperty;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.ExcelAttribute;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import org.hibernate.validator.constraints.Length;

import java.time.LocalDateTime;

/**
 * 社保士兵返回的数据记录表
 *
 * @author hgw
 * @date 2024-12-12 09:40:55
 */
@Data
@TableName("t_social_friend_back_log")
@Schema(description = "社保士兵返回的数据记录表")
public class TSocialFriendBackLog {

	/**
	 * 主键
	 */
	@TableId(type = IdType.ASSIGN_ID)
	@ExcelProperty("主键")
	@Schema(description = "主键")
	private String id;
	/**
	 * 社保ID
	 */
	@ExcelAttribute(name = "社保ID", maxLength = 32)
	@Length(max = 32, message = "社保ID不能超过32个字符")
	@ExcelProperty("社保ID")
	@Schema(description = "社保ID")
	private String socialId;
	/**
	 * 请求ID
	 */
	@ExcelAttribute(name = "请求ID", maxLength = 50)
	@Length(max = 50, message = "请求ID不能超过50个字符")
	@ExcelProperty("请求ID")
	@Schema(description = "请求ID")
	private String requestId;

	@ExcelAttribute(name = "类型")
	@ExcelProperty("类型")
	@Schema(description = "类型1社保增 2社保减 3医保增 4医保减 5推送的日志")
	private Integer type;

	/**
	 * 日志
	 */
	@ExcelAttribute(name = "日志")
	@ExcelProperty("日志")
	@Schema(description = "日志")
	private String logInfo;
	/**
	 * 创建时间
	 */
	@ExcelAttribute(name = "创建时间", isDate = true)
	@ExcelProperty("创建时间")
	@Schema(description = "创建时间")
	private LocalDateTime createTime;

}
